<?php
//
// Docker Config Wizard
// Copyright (c) 2018-2021 Nagios Enterprises, LLC. All rights reserved.
//

include_once(dirname(__FILE__).'/../configwizardhelper.inc.php');

// Initialization stuff
pre_init();
init_session();

// Grab GET or POST variables and check pre-reqs
grab_request_vars();
check_prereqs();
check_authentication(false);

$mode = grab_request_var('mode', 'containers');
if (!in_array($mode, array('containers', 'networks'))) {
	$mode = 'containers';
}

$objects = array();

$cert = escapeshellarg(grab_request_var('cert', ''));
if (!empty($cert) && $cert !== "''") {
	$cert = " --cert=" . escapeshellarg($cert); 
}
else {
	$cert = "";
}

$key = escapeshellarg(grab_request_var('key', ''));
if (!empty($key) && $key !== "''") {
	$key = " --key=" . escapeshellarg($key); 
}
else {
	$key = "";
}

$cacert = escapeshellarg(grab_request_var('cacert', ''));
if (!empty($cacert) && $cacert !== "''") {
	$cacert = " --cacert=" . escapeshellarg($cacert); 
}
else {
	$cacert = "";
}

$host_addr = grab_request_var('host', '');

if (!$host_addr) {
	echo json_encode("error_host");
	exit();
}
if (substr($host_addr, -1) !== '/') {
	$host_addr .= '/';
}


if ($mode === 'containers')
	$mode .= '/json';
else 
	$mode .= '/';

$host_addr .= $mode . '?all=true';
$host_addr = escapeshellarg($host_addr);

$cmd = 'curl --connect-timeout 10 ' . $host_addr . ' -g ' . $cert . $key . $cacert;
$output = array();
$ret = 0;
exec($cmd, $output, $ret);

if ($ret > 0) {
	echo json_encode("error_curl");
	exit();
}

$output = implode("\n", $output);

$output = json_decode($output, true);

if (isset($output['message'])) {
	$output['cmd'] = $cmd;
	echo json_encode($output);
	exit();
}

foreach($output as $item) {

	preg_replace("/[^a-f0-9]/", '', $item['Id']);
	$name_or_id = $item['Id'];

	if (array_key_exists('Names', $item) && is_array($item['Names'])) {
		preg_replace("/[^a-z_]/", '', $item['Names'][0]);
		$name_or_id = $item['Names'][0];
	}
	else if (array_key_exists('Name', $item)) {
		preg_replace("/[^a-z_]/", '', $item['Name']);
		$name_or_id = $item['Name'];	
	}

	$objects[] = $name_or_id;
}

echo json_encode($objects);

exit();